=== modified file 'find-rcbuggy-problem-packages' (properties changed: -x to +x)
--- find-rcbuggy-problem-packages	2019-08-28 02:51:11 +0000
+++ find-rcbuggy-problem-packages	2019-09-01 22:57:29 +0000
@@ -1,12 +1,27 @@
 #!/usr/bin/python3
 
 import sys
+import subprocess
 
 import yaml
 
 with open(sys.argv[1]) as fp:
     ubuntu_excuses = yaml.load(fp, Loader=yaml.CSafeLoader)
 with open(sys.argv[2]) as fp:
+    srcpkg = None
+    uninstallable_to_src_pkg = {}
+    for line in fp:
+        parts = line.split()
+        if len(parts) >= 2:
+            if parts[0] == 'skipped:':
+                srcpkg = None
+                if parts[2].startswith('('):
+                    srcpkg = parts[1]
+            if srcpkg is not None and parts[0] == '*':
+                for pkg in parts[2:]:
+                    pkg = pkg.strip(',')
+                    uninstallable_to_src_pkg.setdefault(pkg, set()).add(srcpkg)
+with open(sys.argv[3]) as fp:
     debian_excuses = yaml.load(fp, Loader=yaml.CSafeLoader)
 
 rc_gone = set()
@@ -18,8 +33,11 @@
         if rc_bug_verdict == "REJECTED_PERMANENTLY":
             rc_gone.add(source['item-name'])
 
+in_proposed_by_autopkgtest_or_missing_binaries = set()
+
 for source in ubuntu_excuses['sources']:
     if 'autopkgtest' in source['reason']:
+        in_proposed_by_autopkgtest_or_missing_binaries.add(source['item-name'])
         for package, results in sorted(source['policy_info']['autopkgtest'].items()):
             package = package.split('/')[0]
             if package not in rc_gone:
@@ -29,3 +47,14 @@
                 if outcome == "REGRESSION":
                     print(package, "blocks", source['item-name'], "by autopkgtest regression")
                     break
+    if 'missing-builds' in source:
+        in_proposed_by_autopkgtest_or_missing_binaries.add(source['item-name'])
+
+for pkg in rc_gone:
+    if pkg not in in_proposed_by_autopkgtest_or_missing_binaries:
+        continue
+    cp = subprocess.run(["chdist", "grep-dctrl-packages", "eoan", "-SwnsPackage", pkg], stdout=subprocess.PIPE, encoding='ascii')
+    bin_pkgs = set(cp.stdout.splitlines())
+    for bin_pkg in sorted(bin_pkgs):
+        if bin_pkg in uninstallable_to_src_pkg:
+            print(pkg, "blocks", sorted(uninstallable_to_src_pkg[bin_pkg]), "by uninstallability of", bin_pkg)

